==> qt-creator-opensource-src-3.3.0.zip: qt-creator-opensource-src-3.3.0/src/plugins/projectexplorer/projectmacroexpander.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "projectmacroexpander.h"
#include "kit.h"
#include "projectexplorerconstants.h"

namespace ProjectExplorer {

ProjectMacroExpander::ProjectMacroExpander(const QString &projectName,
                                           const Kit *kit, const QString &bcName)
{
    registerVariable(Constants::VAR_CURRENTPROJECT_NAME,
                     QCoreApplication::translate("ProjectExplorer", "Name of current project"),
                     [projectName] { return projectName; });

    registerVariable(Constants::VAR_CURRENTBUILD_NAME,
                     QCoreApplication::translate("ProjectExplorer", "Name of current build"),
                     [bcName] { return bcName; });

    registerSubProvider([kit] { return kit->macroExpander(); });
}

} // namespace ProjectExplorer

==> qt-creator-opensource-src-3.6.1.zip: qt-creator-opensource-src-3.6.1/src/plugins/projectexplorer/projectmacroexpander.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "projectmacroexpander.h"
#include "kit.h"
#include "projectexplorerconstants.h"

namespace ProjectExplorer {

ProjectMacroExpander::ProjectMacroExpander(const QString &projectName,
                                           const Kit *kit, const QString &bcName,
                                           BuildConfiguration::BuildType buildType)
{
    registerVariable(Constants::VAR_CURRENTPROJECT_NAME,
                     QCoreApplication::translate("ProjectExplorer", "Name of current project"),
                     [projectName] { return projectName; });

    registerVariable(Constants::VAR_CURRENTBUILD_NAME,
                     QCoreApplication::translate("ProjectExplorer", "Name of current build"),
                     [bcName] { return bcName; });

    registerVariable(Constants::VAR_CURRENTBUILD_TYPE,
                     QCoreApplication::translate("ProjectExplorer", "Type of current build"),
                     [buildType] { return BuildConfiguration::buildTypeName(buildType); });

    registerSubProvider([kit] { return kit->macroExpander(); });
}

} // namespace ProjectExplorer
